@@ -4,7 +4,7 @@
 //  Tree control used for the survey tree.
 //
 //  Copyright (C) 2001, Mark R. Shinwell.
-//  Copyright (C) 2002,2006 Olly Betts
+//  Copyright (C) 2002,2006,2018 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,8 @@
 
 #include "wx.h"
 
+#include "model.h"
+
 class MainFrm;
 class LabelInfo;
 
@@ -50,11 +52,15 @@ class AvenTreeCtrl : public wxTreeCtrl {
     wxColour m_BackgroundColour;
     bool m_SelValid;
     const TreeData* menu_data;
+    wxTreeItemId menu_item;
+
+    SurveyFilter filter;
 
 public:
     AvenTreeCtrl(MainFrm* parent, wxWindow* window_parent);
 
-    void SetEnabled(bool enabled = true);
+    void FillTree(const wxString& root_name);
+
     void UnselectAll();
 
     void OnMouseMove(wxMouseEvent& event);
@@ -65,12 +71,18 @@ public:
     void OnMenu(wxTreeEvent& e);
 
     void OnRestrict(wxCommandEvent& e);
+    void OnHide(wxCommandEvent& e);
+    void OnShow(wxCommandEvent& e);
+    void OnHideSiblings(wxCommandEvent& e);
+    void OnStateClick(wxTreeEvent& e);
 
     bool GetSelectionData(wxTreeItemData**) const;
 
     void SetHere(wxTreeItemId pos);
 
-    void DeleteAllItems();
+    const SurveyFilter* GetFilter() const {
+	return filter.empty() ? NULL : &filter;
+    }
 
 private:
     DECLARE_EVENT_TABLE()
