@@ -1,6 +1,6 @@
 /* cavern.h
  * SURVEX Cave surveying software - header file
- * Copyright (C) 1991-2003,2005,2006,2010,2013,2014,2015,2016,2019 Olly Betts
+ * Copyright (C) 1991-2003,2005,2006,2010,2013,2014,2015,2016,2019,2021 Olly Betts
  * Copyright (C) 2004 Simeon Warner
  *
  * This program is free software; you can redistribute it and/or modify
@@ -108,7 +108,8 @@ typedef enum {
 
 /* masks for quantities which are length and angles respectively */
 #define LEN_QMASK (BIT(Q_LENGTH) | BIT(Q_BACKLENGTH) | BIT(Q_DEPTH) |\
-   BIT(Q_DX) | BIT(Q_DY) | BIT(Q_DZ) | BIT(Q_POS) | BIT(Q_COUNT))
+   BIT(Q_DX) | BIT(Q_DY) | BIT(Q_DZ) | BIT(Q_POS) | BIT(Q_COUNT) |\
+   BIT(Q_LEFT) | BIT(Q_RIGHT) | BIT(Q_UP) | BIT(Q_DOWN))
 #define ANG_QMASK (BIT(Q_BEARING) | BIT(Q_BACKBEARING) |\
    BIT(Q_GRADIENT) | BIT(Q_BACKGRADIENT) | BIT(Q_PLUMB) | BIT(Q_LEVEL) |\
    BIT(Q_DECLINATION))
@@ -116,8 +117,8 @@ typedef enum {
 /* if you add/change the order, check factor_tab in commands.c */
 typedef enum {
    UNITS_NULL = -1, UNITS_METRES, UNITS_FEET, UNITS_YARDS,
-   UNITS_DEGS, UNITS_GRADS, UNITS_PERCENT, UNITS_MINUTES, UNITS_MAC,
-   UNITS_DEPRECATED_ALIAS_FOR_GRADS
+   UNITS_DEGS, UNITS_QUADRANTS, UNITS_GRADS, UNITS_PERCENT, UNITS_MINUTES,
+   UNITS_MAC, UNITS_DEPRECATED_ALIAS_FOR_GRADS
 } u_units;
 
 /* don't reorder these values!  They need to match with img.h too */
@@ -321,6 +322,8 @@ typedef struct Settings {
    unsigned int Truncate;
    bool f_clino_percent;
    bool f_backclino_percent;
+   bool f_bearing_quadrants;
+   bool f_backbearing_quadrants;
    bool dash_for_anon_wall_station;
    unsigned char infer;
    enum {OFF, LOWER, UPPER} Case;
