@@ -172,6 +172,7 @@ default_units(settings *s)
 	 s->units[quantity] = (real)1.0; /* metres */
    }
    s->f_clino_percent = s->f_backclino_percent = fFalse;
+   s->f_bearing_quadrants = s->f_backbearing_quadrants = fFalse;
 }
 
 void
@@ -334,13 +335,14 @@ static const sztok cmd_tab[] = {
 /* ordering must be the same as the units enum */
 const real factor_tab[] = {
    1.0, METRES_PER_FOOT, (METRES_PER_FOOT*3.0),
-   (M_PI/180.0), (M_PI/200.0), 0.01, (M_PI/180.0/60.0)
+   (M_PI/180.0), (M_PI/180.0), (M_PI/200.0), 0.01, (M_PI/180.0/60.0)
 };
 
 const int units_to_msgno[] = {
     /*m*/424,
     /*ft*/428,
     -1, /* yards */
+    /*°*/344, /* quadrants */
     /*°*/344,
     /*ᵍ*/345,
     /*%*/96,
@@ -379,6 +381,8 @@ get_units(unsigned long qmask, bool percent_ok)
 	{"MINUTES",	  UNITS_MINUTES },
 	{"PERCENT",	  UNITS_PERCENT },
 	{"PERCENTAGE",    UNITS_PERCENT },
+	{"QUADRANTS",	  UNITS_QUADRANTS },
+	{"QUADS",	  UNITS_QUADRANTS },
 	{"YARDS",	  UNITS_YARDS },
 	{NULL,		  UNITS_NULL }
    };
@@ -405,6 +409,10 @@ get_units(unsigned long qmask, bool percent_ok)
        !(qmask & ~(BIT(Q_GRADIENT)|BIT(Q_BACKGRADIENT)))) {
       return units;
    }
+   if (units == UNITS_QUADRANTS &&
+       !(qmask & ~(BIT(Q_BEARING)|BIT(Q_BACKBEARING)))) {
+      return units;
+   }
    if (((qmask & LEN_QMASK) && !TSTBIT(LEN_UMASK, units)) ||
        ((qmask & ANG_QMASK) && !TSTBIT(ANG_UMASK, units))) {
       /* TRANSLATORS: Note: In English you talk about the *units* of a single
@@ -1279,19 +1287,15 @@ cmd_data(void)
 
 #define m_multi (BIT(Station) | BIT(Count) | BIT(Depth))
 
-   int style, k = 0, kMac;
-   reading *new_order, d;
+   int style, k = 0;
+   reading d;
    unsigned long mUsed = 0;
-   char *style_name;
    int old_style = pcs->style;
 
    /* after a bad *data command ignore survey data until the next
     * *data command to avoid an avalanche of errors */
    pcs->style = STYLE_IGNORE;
 
-   kMac = 6; /* minimum for NORMAL style */
-   new_order = osmalloc(kMac * sizeof(reading));
-
    get_token();
    style = match_tok(styletab, TABSIZE(styletab));
 
@@ -1305,7 +1309,7 @@ cmd_data(void)
 	 /* "*data" reinitialises the current style - for *data passage that
 	  * breaks the passage.
 	  */
-	 style = old_style;
+	 pcs->style = style = old_style;
 	 goto reinit_style;
       }
       /* TRANSLATORS: e.g. trying to refer to an invalid FNORD data style */
@@ -1329,7 +1333,9 @@ cmd_data(void)
    }
 #endif
 
-   style_name = osstrdup(buffer);
+   int kMac = 6; /* minimum for NORMAL style */
+   reading *new_order = osmalloc(kMac * sizeof(reading));
+   char *style_name = osstrdup(buffer);
    do {
       filepos fp;
       get_pos(&fp);
@@ -1592,6 +1598,13 @@ cmd_units(void)
    if (TSTBIT(qmask, Q_BACKGRADIENT))
       pcs->f_backclino_percent = (units == UNITS_PERCENT);
 
+   if (TSTBIT(qmask, Q_BEARING)) {
+      pcs->f_bearing_quadrants = (units == UNITS_QUADRANTS);
+   }
+   if (TSTBIT(qmask, Q_BACKBEARING)) {
+      pcs->f_backbearing_quadrants = (units == UNITS_QUADRANTS);
+   }
+
    if (factor == HUGE_REAL) {
       factor = factor_tab[units];
    } else {
