@@ -96,6 +96,7 @@ enum {
     COLOUR_BY_GRADIENT,
     COLOUR_BY_LENGTH,
     COLOUR_BY_SURVEY,
+    COLOUR_BY_STYLE,
     COLOUR_BY_LIMIT_ // Leave this last.
 };
 
@@ -140,6 +141,7 @@ class GfxCore : public GLACanvas {
 	LIST_ERROR_KEY,
 	LIST_GRADIENT_KEY,
 	LIST_LENGTH_KEY,
+	LIST_STYLE_KEY,
 	LIST_UNDERGROUND_LEGS,
 	LIST_TUBES,
 	LIST_SURFACE_LEGS,
@@ -317,6 +319,7 @@ private:
     void DrawErrorKey();
     void DrawGradientKey();
     void DrawLengthKey();
+    void DrawStyleKey();
     void DrawCompass();
     void DrawClino();
     void DrawClinoBack();
@@ -595,6 +598,7 @@ public:
     void AddPolylineGradient(const traverse & centreline);
     void AddPolylineLength(const traverse & centreline);
     void AddPolylineSurvey(const traverse & centreline);
+    void AddPolylineStyle(const traverse & centreline);
     void AddQuadrilateral(const Vector3 &a, const Vector3 &b,
 			  const Vector3 &c, const Vector3 &d);
     void AddPolylineShadow(const traverse & centreline);
