@@ -375,15 +375,6 @@ static void
 choleski(real *M, real *B, long n)
 {
    int i, j, k;
-#ifndef NO_PERCENTAGE
-   unsigned long flopsTot, flops = 0, temp = 0;
-#define do_percent(N) BLK(flops += (N); printf("%d%%\r", (int)((100.0 * flops) / flopsTot));)
-
-   /* calc as double so we don't overflow a unsigned long with intermediate results */
-   flopsTot = (unsigned long)(n * (2.0 * n * n + 9.0 * n - 5.0) / 6.0);
-   /* 3*n*(n-1)/2 + n*(n-1)*(n-2)/3 + n*(n-1)/2 + n + n*(n-1)/2; */
-   /* n*(9*n-5 + 2*n*n )/6 ; */
-#endif
 
    for (j = 1; j < n; j++) {
       real V;
@@ -395,13 +386,6 @@ choleski(real *M, real *B, long n)
       V = (real)0.0;
       for (k = 0; k < j; k++) V += M(j,k) * M(j,k) * M(k,k);
       M(j,j) -= V; /* may be best to add M() last for numerical reasons too */
-
-#ifndef NO_PERCENTAGE
-      if (fPercent) {
-	 temp += ((unsigned long)j + j) + 1ul; /* avoid multiplies */
-	 do_percent(temp);
-      }
-#endif
    }
 
    /* Multiply x by L inverse */
@@ -411,22 +395,11 @@ choleski(real *M, real *B, long n)
       }
    }
 
-#ifndef NO_PERCENTAGE
-   if (fPercent) {
-      temp = (unsigned long)n * (n - 1ul) / 2ul; /* needed again lower down */
-      do_percent(temp);
-   }
-#endif
-
    /* Multiply x by D inverse */
    for (i = 0; i < n; i++) {
       B[i] /= M(i,i);
    }
 
-#ifndef NO_PERCENTAGE
-   if (fPercent) do_percent((unsigned long)n);
-#endif
-
    /* Multiply x by (L transpose) inverse */
    for (i = (int)(n - 1); i > 0; i--) {
       for (j = i - 1; j >= 0; j--) {
@@ -434,11 +407,6 @@ choleski(real *M, real *B, long n)
       }
    }
 
-#ifndef NO_PERCENTAGE
-   if (fPercent) do_percent(temp);
-# undef do_percent
-#endif
-
    /* printf("\n%ld/%ld\n\n",flops,flopsTot); */
 }
 
