@@ -1,5 +1,5 @@
 /* useful.c
- * Copyright (C) 1993-2001,2003,2010 Olly Betts
+ * Copyright (C) 1993-2021 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,15 +26,17 @@
 #ifdef WORDS_BIGENDIAN
 
 extern void
-useful_put16(int16_t w, FILE *fh)
+useful_put16(int16_t word, FILE *fh)
 {
+   uint16_t w = (uint16_t)word;
    PUTC((char)(w), fh);
    PUTC((char)(w >> 8l), fh);
 }
 
 extern void
-useful_put32(int32_t w, FILE *fh)
+useful_put32(int32_t word, FILE *fh)
 {
+   uint32_t w = (uint32_t)word;
    PUTC((char)(w), fh);
    PUTC((char)(w >> 8l), fh);
    PUTC((char)(w >> 16l), fh);
@@ -44,20 +46,20 @@ useful_put32(int32_t w, FILE *fh)
 extern int16_t
 useful_get16(FILE *fh)
 {
-   int16_t w;
+   uint16_t w;
    w = GETC(fh);
-   w |= (int16_t)(GETC(fh) << 8l);
-   return w;
+   w |= (uint16_t)(GETC(fh) << 8l);
+   return (int16_t)w;
 }
 
 extern int32_t
 useful_get32(FILE *fh)
 {
-   int32_t w;
+   uint32_t w;
    w = GETC(fh);
-   w |= (int32_t)(GETC(fh) << 8l);
-   w |= (int32_t)(GETC(fh) << 16l);
-   w |= (int32_t)(GETC(fh) << 24l);
-   return w;
+   w |= (uint32_t)(GETC(fh) << 8l);
+   w |= (uint32_t)(GETC(fh) << 16l);
+   w |= (uint32_t)(GETC(fh) << 24l);
+   return (int32_t)w;
 }
 #endif
